# Statistics API

Hypothesis tests, correlations, effect sizes, and design utilities for FoodSpec.

::: foodspec.stats.hypothesis_tests

::: foodspec.stats.correlations

::: foodspec.stats.effects

::: foodspec.stats.design

::: foodspec.stats.robustness
